Installation — copepodTCR 0.3.2 documentation

# Installation

You can install the package with pip:

    pip install copepodTCR

Or with conda:

    conda install -c vasilisa.kovaleva copepodTCR

## Requirements

Required packages should be installed simulataneously with the copepodTCR packages.

But if they were not, here is the list of requirements:

- pandas>=1.5.3

  >     pip install "pandas>=1.5.3"

- numpy>=1.23.5

  >     pip install "numpy>=1.23.5"

- cvxpy>=1.3.2

  >     pip install "cvxpy>=1.3.2"

- trimesh>=3.23.5

  >     pip install "trimesh>=3.23.5"

- PyMC>=5.9.2

  >     pip install "pymc>=5.9.2"

- Arviz>=5.9.2

  >     pip install "arviz>=0.16.1"